@@ -68,6 +68,7 @@ __all__ = (
     "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
     "CognitoOptionsStatusTypeDef",
     "CognitoOptionsTypeDef",
+    "ColdStorageOptionsTypeDef",
     "CompatibleVersionsMapTypeDef",
     "CreateElasticsearchDomainResponseTypeDef",
     "CreateOutboundCrossClusterSearchConnectionResponseTypeDef",
@@ -344,6 +345,13 @@ CognitoOptionsTypeDef = TypedDict(
     total=False,
 )
 
+ColdStorageOptionsTypeDef = TypedDict(
+    "ColdStorageOptionsTypeDef",
+    {
+        "Enabled": bool,
+    },
+)
+
 CompatibleVersionsMapTypeDef = TypedDict(
     "CompatibleVersionsMapTypeDef",
     {
@@ -630,6 +638,7 @@ ElasticsearchClusterConfigTypeDef = TypedDict(
         "WarmEnabled": bool,
         "WarmType": ESWarmPartitionInstanceTypeType,
         "WarmCount": int,
+        "ColdStorageOptions": "ColdStorageOptionsTypeDef",
     },
     total=False,
 )
